@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-use version;
 
 package WebService::Nestoria::Search;
-$WebService::Nestoria::Search::VERSION = '1.022013';
+
+our $VERSION = '1.14';
+
 use Carp;
-use URI;
 use WebService::Nestoria::Search::Request;
 use WebService::Nestoria::Search::MetadataResponse;
 
@@ -13,15 +13,11 @@ use WebService::Nestoria::Search::MetadataResponse;
 
 WebService::Nestoria::Search - Perl interface to the Nestoria Search public API.
 
-=head1 VERSION
-
-version 1.022013
-
 =head1 SYNOPSIS
 
-WebService::Nestoria::Search provides a Perl interface to the public API of Nestoria, a vertical search engine for property listings.
+WebService::Nestoria::Search provides a Perl interface to the public API of Nestoria, a vertical search engine for property listings. Nestoria currently has listings for the UK, Germany, Italy and Spain, which can be accessed via the web at www.nestoria.co.uk, www.nestoria.de, www.nestoria.co.it and www.nestoria.es.
 
-WebService::Nestoria::Search is currently written to be used with v1.22 of the Nestoria API.
+WebService::Nestoria::Search is currently written to be used with v1.14 of the Nestoria API.
 
 Functions and documentation are split over WebService::Nestoria::Search, WebService::Nestoria::Search::Request, WebService::Nestoria::Search::Response and WeebService::Nestoria::Search::Result. However you need only ever use WebService::Nestoria::Search, and the others will be used as necessary.
 
@@ -38,7 +34,6 @@ The possible parameters and their defaults are as follows:
     encoding            (default: 'json')
     pretty              (default: 0)
     number_of_results
-    page
     place_name
     south_west
     north_east
@@ -50,10 +45,6 @@ The possible parameters and their defaults are as follows:
     price_min
     bedroom_max
     bedroom_min
-    bathroom_max
-    bathroom_min
-    room_max
-    room_min
     size_max
     size_min
     sort
@@ -62,21 +53,19 @@ The possible parameters and their defaults are as follows:
 
 If parameters are passed to C<new> they are used as the defaults for all calls to the API. Otherwise they can be passed to the querying functions (eg. C<query>) as per-search parameters.
 
-You should never have to set the 'action' parameter yourself, it is implied by the method you choose to use to run the query.
-
 =head2 Simple Example
 
     use WebService::Nestoria::Search;
 
-    my $NS = WebService::Nestoria::Search->new(
+    my $NS = new WebService::Nestoria::Search(
         place_name          => 'soho',
-        listing_type        => 'rent',
+        listing_type        => 'let',
         property_type       => 'flat',
         price_max           => '500',
         number_of_results   => '10',
     );
 
-    my @results = $NS->results(
+    my @results = WebService::Nestoria::Search->results(
         keywords            => 'garden,hot_tub,mews',
         keywords_exclude    => 'cottage,wood_floor'
     );
@@ -108,27 +97,22 @@ C<@listings> is an array of WebService::Nestoria::Search::Result objects.
     while (my $result = $response->next_result) {
         print $result->get_thumb_url, "\n";
     }
-
+    
 =head2 Using a bounding box
-
+   
     my @bound_results = $ns->results('south_west' => '51.473685,-0.148315', 'north_east' => '50.473685,-0.248315');
 
     foreach my $result  (@bound_results) {
         print $result->get_title, "\n";
     }
-
+    
 =cut
 
 ##
 ## Configuration details for searching the Nestoria listings database
 ##
 my %Config = (
-    'AppId'                   => sprintf("%s %s",
-        __PACKAGE__,
-        $WebService::Nestoria::Search::VERSION
-            ? version->parse($WebService::Nestoria::Search::VERSION)->normal
-            : ""
-    ),
+    'AppId'                   => "WebService::Nestoria::Search $VERSION",
     'MaxResults'              => '1000',
 
     ## keys indicate the universe of allowable arguments
@@ -138,7 +122,6 @@ my %Config = (
         'encoding'            => 'json',
         'pretty'              => '0',     # pretty JSON results not needed
         'number_of_results'   => undef,   # defaults to 20 their end
-        'page'                => undef,   # defautls to 1 on their end
         'place_name'          => undef,
         'south_west'          => undef,
         'north_east'          => undef,
@@ -150,32 +133,25 @@ my %Config = (
         'price_min'           => undef,   # defaults to 'min'
         'bedroom_max'         => undef,   # defaults to 'max'
         'bedroom_min'         => undef,   # defaults to 'min'
-        'bathroom_max'        => undef,   # defaults to 'max'
-        'bathroom_min'        => undef,   # defaults to 'min'
-        'room_max'            => undef,   # defaults to 'max'
-        'room_min'            => undef,   # defaults to 'min'
-        'size_max'            => undef,   # defaults to 'max'
-        'size_min'            => undef,   # defaults to 'min'
+        'size_max'            => undef,   # only for Spain
+        'size_min'            => undef,   # only for Spain
         'sort'                => undef,   # defaults to 'nestoria_rank'
         'keywords'            => undef,   # defaults to an empty list
         'keywords_exclude'    => undef,   # defaults to an empty list
         'callback'            => undef,
     },
-
+    
     'Urls' => {
-        'au'                  => 'http://api.nestoria.com.au/api',
-        'br'                  => 'http://api.nestoria.com.br/api',
-        'de'                  => 'http://api.nestoria.de/api',
-        'es'                  => 'http://api.nestoria.es/api',
-        'fr'                  => 'http://api.nestoria.fr/api',
-        'in'                  => 'http://api.nestoria.in/api',
         'uk'                  => 'http://api.nestoria.co.uk/api',
+        'es'                  => 'http://api.nestoria.es/api',
+        'de'                  => 'http://api.nestoria.de/api',
+        'it'                  => 'http://api.nestoria.it/api',
+
     },
 );
 
 ## filled in Search/Request.pm
-our $RecentRequestUrl;
-our $SleepTime = 2;
+our $RecentRequsetUrl;
 
 my %GlobalDefaults = (
     'warnings'                => '1',
@@ -218,121 +194,127 @@ sub _carp_on_error {
 
 my $validate_allow_all = sub {
     ## allow any defined input
+    
     return defined shift;
 };
 
 my $validate_lat_long = sub {
-    my $val = shift;
+    my $val = shift || return 0;
+
     my ($lat, $long) = split (/,/, $val);
+
     return _validate_lat($lat) && _validate_long($long);
 };
 
 my $validate_radius = sub {
-    my $val = shift;
+    my $val = shift || return 0;
+
     my ($lat,$long,$radius) = split(/,/, $val);
-    return _validate_lat($lat) && _validate_long($long) &&
-           ($radius =~ m/^\d+(km|mi)$/);
+
+    return _validate_lat($lat) && _validate_long($long)
+        && $radius =~ m/^\d+(km|mi)$/;
 };
 
 ## latitude is a float between -180 and 180
 sub _validate_lat {
-    my $val = shift;
+    my $val = shift || return 0;
+
     if ( defined($val) && $val =~ /^[\+\-]?\d+\.?\d*$/ ) {
         return -180 <= $val && $val <= 180;
     }
     else {
-        return;
+        return 0;
     }
 }
 
 ## longitude is a float between -90 and 90
 sub _validate_long {
-    my $val = shift;
+    my $val = shift || return 0;
+
     if ( defined($val) && $val =~ /^[\+\-]?\d+\.?\d*$/ ) {
         return -90 <= $val && $val <= 90;
     }
     else {
-        return;
+        return 0;
     }
 }
 
-my $validate_positive_integer = sub {
-    my $val = shift;
-    return ( $val =~ /^\d+$/ && $val > 0 );
+my $validate_number_of_results = sub {
+    my $val = shift || return 0;
+
+    return ( $val =~ /^\d+$/ );
 };
 
 my $validate_listing_type = sub {
-    my $val = shift;
+    my $val = shift || return 0;
+
     return grep { $val eq $_ } qw(buy rent share);
 };
 
 my $validate_property_type = sub {
-    my $val = shift;
-    return grep { $val eq $_ } qw(all house flat land);
+    my $val = shift || return 0;
+
+    return grep { $val eq $_ } qw(all house flat);
 };
 
 my $validate_max = sub {
-    my $val = shift;
+    my $val = shift || return 0;
+
     return $val eq 'max' || $val =~ /^\d+$/;
 };
 
 my $validate_min = sub {
-    my $val = shift;
+    my $val = shift || return 0;
+
     return $val eq 'min' || $val =~ /^\d+$/;
 };
 
 my $validate_sort = sub {
-    my $val = shift;
+    my $val = shift || return 0;
+
     return grep { $val eq $_ } qw(bedroom_lowhigh bedroom_highlow
                                   price_lowhigh price_highlow
                                   newest oldest);
-};
+}; 
 
 my $validate_version = sub {
-    my $val = shift;
-    return $val =~ m/^[\d.]+$/;
+    my $val = shift || return 0;
+
+    return $val =~ m/[\d.]+/;
 };
 
 my $validate_action = sub {
-    my $val = shift;
+    my $val = shift || return 0;
+
     return grep { $val eq $_ } qw(search_listings echo keywords metadata);
 };
 
 my $validate_encoding = sub {
-    my $val = shift;
+    my $val = shift || return 0;
+
     return grep { $val eq $_ } qw(json xml);
 };
 
 my $validate_pretty = sub {
     my $val = shift;
-    return $val == 0 || $val == 1;
-};
 
-my $validate_country = sub {
-    my $val = shift;
-    return $Config{'Urls'}{$val};
+    return defined $val && ($val == 0 || $val == 1);
 };
 
 ## Mapping from arg name to validation sub
 my %ValidateRoutine = (
-    'country'             => $validate_country,
     'place_name'          => $validate_allow_all,
     'south_west'          => $validate_lat_long,
     'north_east'          => $validate_lat_long,
     'centre_point'        => $validate_lat_long,
     'radius'              => $validate_radius,
-    'number_of_results'   => $validate_positive_integer,
-    'page'                => $validate_positive_integer,
+    'number_of_results'   => $validate_number_of_results,
     'listing_type'        => $validate_listing_type,
     'property_type'       => $validate_property_type,
     'price_max'           => $validate_max,
     'price_min'           => $validate_min,
     'bedroom_max'         => $validate_max,
     'bedroom_min'         => $validate_min,
-    'bathroom_max'        => $validate_max,
-    'bathroom_min'        => $validate_min,
-    'room_max'            => $validate_max,
-    'room_min'            => $validate_min,
     'size_max'            => $validate_max,
     'size_min'            => $validate_min,
     'sort'                => $validate_sort,
@@ -344,7 +326,7 @@ my %ValidateRoutine = (
     'pretty'              => $validate_pretty,
     'has_photo'           => $validate_allow_all,
     'guid'                => $validate_allow_all,
-);
+); 
 
 sub _validate {
     my $key = shift;
@@ -378,7 +360,7 @@ Creates a WebService::Nestoria::Search object.  On error sets C<$@> and returns
 
 If given 'request' parameters (eg. place_name, listing_type) these become defaults for all calls to the API.
 
-    my %args = (warnings => 0, listing_type => 'rent', place_name => 'soho');
+    my %args = (warnings => 0, listing_type => 'let', place_name => 'soho');
     my $NS = WebService::Nestoria::Search->new(%args);
 
 =cut
@@ -443,15 +425,11 @@ sub request {
     if ( @_ % 2 != 0 ) {
         return _carp_on_error("wrong arg count for request");
     }
-
+    
     my %args = @_;
 
     unless ( ref $self ) {
-        $self = $self->new;
-    }
-
-    foreach my $key ( keys %GlobalDefaults ) {
-        $args{$key} ||= $GlobalDefaults{$key};
+        $self = new $self;
     }
 
     foreach my $key ( keys %{ $self->{Defaults} } ) {
@@ -473,7 +451,7 @@ sub request {
     }
 
     my %params;
-    $params{ActionUrl} = $Config{Urls}->{$args{country}};
+    $params{ActionUrl} = $Config{Urls}->{$GlobalDefaults{country}};
     $params{AppId}     = $Config{AppId};
     $params{Params}    = \%args;
 
@@ -481,7 +459,7 @@ sub request {
         return _carp_on_error("number_of_results $args{number_of_results} too large, maximum is $Config{MaxResults}");
     }
 
-    return WebService::Nestoria::Search::Request->new(\%params);
+    return new WebService::Nestoria::Search::Request (\%params);
 }
 
 =head2 query
@@ -499,9 +477,9 @@ This is a shortcut for
 
 sub query {
     my $self = shift;
-
+    
     unless ( ref $self ) {
-        $self = $self->new;
+        $self = new $self;
     }
 
     if ( my $request = $self->request(@_) ) {
@@ -530,9 +508,9 @@ sub results {
     my $self = shift;
 
     unless ( ref $self ) {
-        $self = $self->new;
+        $self = new $self;
     }
-
+    
     my $response = $self->query(@_);
 
     unless ( $response ) {
@@ -602,91 +580,16 @@ sub metadata {
     my $self = shift;
 
     unless ( ref $self ) {
-        $self = $self->new;
+        $self = new $self;
     }
 
     my %params = ( action => 'metadata' );
 
     my $response = $self->query(%params, @_);
 
-    return WebService::Nestoria::Search::MetadataResponse->new($response->get_hashref);
+    return new WebService::Nestoria::Search::MetadataResponse($response->get_hashref);
 }
 
-=head2 last_request_uri
-
-Returns a URI object representing the URL that was last fetched by
-WebService::Nestoria::Search::Request.
-
-=cut
-
-sub last_request_uri {
-    return URI->new($RecentRequestUrl);
-}
-
-=head2 last_request_url
-
-Returns the URL that was last fetched by WebService::Nestoria::Search::Request.
-
-=cut
-
-sub last_request_url {
-    return $RecentRequestUrl;
-}
-
-=head2 override_user_agent
-
-Takes an LWP::UserAgent-ish object and uses that object for all requests.
-
-Note this is a class method so will affect all instances being used in your
-process.
-
-    WebService::Nestoria::Search->override_user_agent($UA);
-
-=cut
-
-sub override_user_agent {
-    my $class = shift;
-    my $UA = shift;
-
-    # allow getting called as ::override_user_agent() instead of
-    # ->override_user_agent() - we're nice like that :-)
-    if (!$UA && $class->can("get")) {
-        $UA = $class;
-    }
-
-    $WebService::Nestoria::Search::Request::UA = $UA;
-
-    return;
-}
-
-=head2 override_sleep_time
-
-Takes a time in seconds to sleep between each request. The default is two
-(2) seconds.
-
-Note that the T&Cs of the Nestoria API explicitly request 1 second between
-requests. To live this requirement contact Nestoria.
-
-    WebService::Nestoria::Search->override_sleep_time(1);
-
-=cut
-
-sub override_sleep_time {
-    my $class = shift;
-    my $sleep_time = shift;
-
-    # allow getting called as ::override_user_agent() instead of
-    # ->override_user_agent() - we're nice like that :-)
-    if (!defined($sleep_time) && !ref($class) && $class =~ m/^\d+$/) {
-        $sleep_time = $class;
-    }
-
-    $WebService::Nestoria::Search::SleepTime = $sleep_time;
-
-    return;
-}
-
-
 =head1 Warnings
 
 Warnings is true by default, and means that errors are output to STDERR as well as being returned via $@. This can be turned off either on the C<use> line
@@ -695,31 +598,13 @@ Warnings is true by default, and means that errors are output to STDERR as well
 
 or when calling C<new>
 
-    my $NS = WebService::Nestoria::Search->new(Warnings => 0);
+    my $NS = new WebService::Nestoria::Search(Warnings => 0);
 
 =head1 Country
 
 Country is an optional parameter which defaults to 'uk'. It affects the URL which is used for fetching results.
 
-Currently the available countries are:
-
-=over 4
-
-=item * br - Brazil
-
-=item * de - Germany
-
-=item * es - Spain
-
-=item * in - India
-
-=item * uk - United Kingdom
-
-=back
-
-Australia (au) supports the metadata requests but not listings requests
-
-Mexico (mx), Italy (it) and France (fr) currently have no API support.
+Currently the available countries are 'uk' for the United Kingdom, 'es' for Spain, 'de' for Germany and 'it' for Italy.
 
 =head1 Non-OO
 
@@ -729,13 +614,12 @@ It is possible to run WebService::Nestoria::Search functions without creating an
 
 =head1 Copyright
 
-Copyright (C) 2014 Lokku Ltd.
+Copyright (C) 2008 Lokku Ltd.
 
 =head1 Author
 
-Alex Balhatchet (alex@lokku.com)
-
-Patches supplied by Yoav Felberbaum, Alistair Francis, Ed Freyfogle
+Alex Balhatchet (kaoru@slackwise.net)
+Yoav Felberbaum (perl@mrdini.com)
 
 =head1 Acknowledgements
 
