@@ -2,10 +2,9 @@ use strict;
 use warnings;
 
 package WebService::Nestoria::Search::Request;
-$WebService::Nestoria::Search::Request::VERSION = '1.022013';
+
 use WebService::Nestoria::Search::Response;
 use JSON;
-use XML::Simple;
 use LWP::UserAgent;
 use HTTP::Request;
 use URI;
@@ -14,10 +13,6 @@ use URI;
 
 WebService::Nestoria::Search::Request - Container object for a WebService::Nestoria::Search request.
 
-=head1 VERSION
-
-version 1.022013
-
 This package is used by WebService::Nestoria::Search and a C<Request> object should never need to be explicitly created by the user.
 
 =cut
@@ -41,7 +36,7 @@ sub uri {
     my $self = shift;
 
     unless ( $self->{_uri} ) {
-        $self->{_uri} = URI->new($self->{ActionUrl}, 'http');
+        $self->{_uri} = new URI ($self->{ActionUrl}, 'http');
         $self->{_uri}->query_form( %{ $self->{Params} } );
     }
     return $self->{_uri};
@@ -75,10 +70,10 @@ sub fetch {
 
     $WebService::Nestoria::Search::RecentRequestUrl = $self->url;
 
-    $UA ||= LWP::UserAgent->new(agent => $self->{AppId});
+    $UA ||= new LWP::UserAgent (agent => $self->{AppId});
 
     my $response = $UA->get($WebService::Nestoria::Search::RecentRequestUrl);
-    sleep $WebService::Nestoria::Search::SleepTime;
+    sleep 2;
 
     unless ( $response && $response->is_success ) {
         $@ = "couldn't make request";
@@ -91,42 +86,25 @@ sub fetch {
         my $response_obj = from_json($raw);
 
         if ( ref $response_obj ) {
-            return WebService::Nestoria::Search::Response->new($response_obj, $raw);
-        }
-        else {
-            return;
-        }
-    }
-    elsif ($self->{Params}{encoding} eq 'xml') {
-        my $response_obj = XMLin($raw);
-     
-        # Returning a listings result in XML will create a hash ref
-        # so it must be forced into an array.
-        if(ref($response_obj->{response}{listings}) eq 'HASH') {
-            $response_obj->{response}{listings} = [ $response_obj->{response}{listings} ];
-        }
-     
-        if (ref($response_obj)) {
-            return WebService::Nestoria::Search::Response->new($response_obj, $raw);
+            return new WebService::Nestoria::Search::Response ($response_obj, $raw);
         }
         else {
             return;
         }
     }
     else {
-        return WebService::Nestoria::Search::Response->new({}, $raw);
+        return new WebService::Nestoria::Search::Response ({}, $raw);
     }
 }
 
 =head1 Copyright
 
-Copyright (C) 2009 Lokku Ltd.
+Copyright (C) 2008 Lokku Ltd.
 
 =head1 Author
 
-Alex Balhatchet (alex@lokku.com)
-
-Patches supplied by Yoav Felberbaum and Alistair Francis.
+Alex Balhatchet (kaoru@slackwise.net)
+Yoav Felberbaum (perl@mrdini.com)
 
 =cut
 
