@@ -2,19 +2,13 @@ use strict;
 use warnings;
 
 package WebService::Nestoria::Search::Response;
-$WebService::Nestoria::Search::Response::VERSION = '1.022013';
+
 use WebService::Nestoria::Search::Result;
-use Carp;
-use URI;
 
 =head1 NAME
 
 WebService::Nestoria::Search::Response - Container object for the result set of a query to the Nestoria Search API.
 
-=head1 VERSION
-
-version 1.022013
-
 This package is used by WebService::Nestoria::Search and a WebService::Nestoria::Search::Response object should never need to be explicitly created by the user.
 
 =cut
@@ -36,8 +30,7 @@ sub new {
         $result->{ordinal} = $i;
         $result->{response} = $self->{data};
 
-        $self->{results}[$i]
-            = WebService::Nestoria::Search::Result->new($result);
+        $self->{results}[$i] = new WebService::Nestoria::Search::Result ($result);
     }
 
     return bless $self, $class;
@@ -50,11 +43,13 @@ sub new {
 
 Returns the raw data returned by the Nestoria API. By default this will be JSON (JavaScript Object Notation.) C<get_json> and C<get_xml> are aliases to C<get_raw>.
 
+Functions other than C<get_raw> only work if encoding was set to 'json'. If encoding is set to anything else ('xml' for example) then C<results> will return an empty array, C<get_hashref> a reference to an empty hash, etc.
+
 =cut
 
 sub get_raw {
     my $self = shift;
-    return $self->{raw};
+    return $self->{json};
 }
 
 sub get_json {
@@ -69,7 +64,7 @@ sub get_xml {
 
 =head2 status_code
 
-Returns the HTTP status code of the response. 200 on success, various other numbers on errors.
+Returns the status code of the response. 200 on success, various other numbers on errors.
 
 =cut
 
@@ -78,62 +73,11 @@ sub status_code {
     return $self->{data}{response}{status_code};
 }
 
-=head2 application_response_code
 
-Returns the application response code, which is much more useful than the status_code for determining the correctness of the response.
-
-Numbers starting 1xx are successes
-
-Numbers starting 2xx are location errors
-
-Numbers starting 5xx are internal server errors
-
-Numbers starting 9xx are invalid request errors
-
-For more information read the Nestoria API documentation: http://www.nestoria.co.uk/help/api-return-codes
-
-=cut
-
-sub application_response_code {
-    my $self = shift;
-    return $self->{data}{response}{application_response_code};
-}
-
-=head2 application_response_text
-
-Returns the text description of the application response code. For example if the application response code is 100, the text is "one unambiguous location".
-
-=cut
-
-sub application_response_text {
-    my $self = shift;
-    return $self->{data}{response}{application_response_text};
-}
-
-=head2 is_success
-
-Uses the status_code and application_response_code, and returns true if the request was a success and false otherwise. Concept stolen straight from LWP::UserAgent.
-
-    if ($response->is_success) {
-        foreach my $result ($response->results) {
-            # do stuff...
-        }
-    }
-    else {
-        die $response->application_response_text;
-    }
-
-=cut
-
-sub is_success {
-    my $self = shift;
-    return ($self->status_code == 200)
-        && ($self->application_response_code =~ m/^1/);
-}
 
 =head2 get_hashref
 
-Returns a reference to a hash that contains exactly what the response from the Nestoria API gave, converted from JSON into a hashref with JSON::from_json()
+Returns a reference to a hash that contains exactly what the response from the Nestoria API gave, converted from JSON into a hashref with JSON::jsonToObj()
 
 =cut
 
@@ -194,36 +138,6 @@ sub attribution_xhtml {
            $self->{data}{response}{attribution}{img_width};
 }
 
-=head2 nestoria_site_uri
-
-Returns a URI object representing the URL for the Nestoria results page for the request.
-
-=cut
-
-sub nestoria_site_uri {
-    my $self = shift;
-
-    if ($self->{data}{response}{link_to_url}) {
-        return URI->new($self->{data}{response}{link_to_url});
-    }
-    else {
-        carp "No 'link_to_url' found in the response";
-    }
-
-    return;
-}
-
-=head2 nestoria_site_url
-
-Returns a URL for the Nestoria results page for the request.
-
-=cut
-
-sub nestoria_site_url {
-    my $self = shift;
-    return $self->nestoria_site_uri->as_string;
-}
-
 =head2 results
 
 Returns an array of WebService::Nestoria::Search::Result objects, each containing data about a single listing returned by the Nestoria API.
@@ -239,7 +153,7 @@ sub results {
 
 Returns the next WebService::Nestoria::Search::Result object to be fetched. When out of listings returns C<undef>, making it suitable for use in while loops.
 
-    while ( $listing = $response->next_result ) {
+    while ( $listing = $result->next_result ) {
         # do something;
     }
 
@@ -252,6 +166,7 @@ sub next_result {
         return $self->{results}[$self->{next_iterator}++];
     }
     else {
+        $self->{next_iterator} = 0;
         return;
     }
 }
@@ -264,18 +179,18 @@ Resets the counter used for next_result.
 
 sub reset {
     my $self = shift;
+
     $self->{next_iterator} = 0;
 }
 
 =head1 Copyright
 
-Copyright (C) 2009 Lokku Ltd.
+Copyright (C) 2008 Lokku Ltd.
 
 =head1 Author
 
-Alex Balhatchet (alex@lokku.com)
-
-Patches supplied by Yoav Felberbaum and Alistair Francis.
+Alex Balhatchet (kaoru@slackwise.net)
+Yoav Felberbaum (perl@mrdini.com)
 
 =cut
 
